@@ -15,7 +15,7 @@ class resplit(RegexUnit):
         super().__init__(regex=regex, multiline=multiline, ignorecase=ignorecase, count=count)
 
     def process(self, data):
-        split = self.args.regex.split
+        split = self.regex.split
         if self.args.count:
             from functools import partial
             split = partial(split, maxsplit=self.args.count)
